@@ -136,6 +136,7 @@ Compositor::~Compositor()
 {
     finish();
     delete cm_selection;
+    s_compositor = NULL;
 }
 
 
@@ -251,12 +252,16 @@ void Compositor::slotCompositingOptionsInitialized()
     new EffectsHandlerImpl(this, m_scene);   // sets also the 'effects' pointer
     connect(effects, SIGNAL(screenGeometryChanged(QSize)), SLOT(addRepaintFull()));
     addRepaintFull();
-    foreach (Client * c, Workspace::self()->clientList())
+    foreach (Client * c, Workspace::self()->clientList()) {
         c->setupCompositing();
+        c->getShadow();
+    }
     foreach (Client * c,  Workspace::self()->desktopList())
         c->setupCompositing();
-    foreach (Unmanaged * c, Workspace::self()->unmanagedList())
+    foreach (Unmanaged * c, Workspace::self()->unmanagedList()) {
         c->setupCompositing();
+        c->getShadow();
+    }
 
     emit compositingToggled(true);
 
