@@ -40,14 +40,19 @@ namespace KWin
 class ThumbnailItem;
 
 class Client;
+class Compositor;
 class Deleted;
 class Unmanaged;
 
 class EffectsHandlerImpl : public EffectsHandler
 {
     Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "org.kde.kwin.Effects")
+    Q_PROPERTY(QStringList activeEffects READ activeEffects)
+    Q_PROPERTY(QStringList loadedEffects READ loadedEffects)
+    Q_PROPERTY(QStringList listOfEffects READ listOfEffects)
 public:
-    EffectsHandlerImpl(CompositingType type);
+    EffectsHandlerImpl(Compositor *compositor, Scene *scene);
     virtual ~EffectsHandlerImpl();
     virtual void prePaintScreen(ScreenPrePaintData& data, int time);
     virtual void paintScreen(int mask, QRegion region, ScreenPaintData& data);
@@ -163,12 +168,6 @@ public:
     void desktopResized(const QSize &size);
 
     virtual void reloadEffect(Effect *effect);
-    bool loadEffect(const QString& name, bool checkDefault = false);
-    void toggleEffect(const QString& name);
-    void unloadEffect(const QString& name);
-    void reconfigureEffect(const QString& name);
-    bool isEffectLoaded(const QString& name) const;
-    QString supportInformation(const QString& name) const;
     QStringList loadedEffects() const;
     QStringList listOfEffects() const;
 
@@ -182,12 +181,19 @@ public Q_SLOTS:
     void slotShowOutline(const QRect &geometry);
     void slotHideOutline();
 
+    // slots for D-Bus interface
+    Q_SCRIPTABLE void reconfigureEffect(const QString& name);
+    Q_SCRIPTABLE bool loadEffect(const QString& name, bool checkDefault = false);
+    Q_SCRIPTABLE void toggleEffect(const QString& name);
+    Q_SCRIPTABLE void unloadEffect(const QString& name);
+    Q_SCRIPTABLE bool isEffectLoaded(const QString& name) const;
+    Q_SCRIPTABLE QString supportInformation(const QString& name) const;
+
 protected Q_SLOTS:
     void slotDesktopChanged(int old, KWin::Client *withClient);
     void slotClientAdded(KWin::Client *c);
     void slotClientShown(KWin::Toplevel*);
     void slotUnmanagedAdded(KWin::Unmanaged *u);
-    void slotUnmanagedShown(KWin::Toplevel*);
     void slotWindowClosed(KWin::Toplevel *c);
     void slotClientActivated(KWin::Client *c);
     void slotDeletedRemoved(KWin::Deleted *d);
@@ -229,6 +235,8 @@ private:
     QList< Effect* >::iterator m_currentPaintEffectFrameIterator;
     QList< Effect* >::iterator m_currentPaintScreenIterator;
     QList< Effect* >::iterator m_currentBuildQuadsIterator;
+    Compositor *m_compositor;
+    Scene *m_scene;
 };
 
 class EffectWindowImpl : public EffectWindow
